<div align="center">

# zq-auth-sdk-python
**自强统一认证 Python SDK**

<!-- markdownlint-disable-next-line MD036 -->
</div>

<p align="center">
  <a href="https://github.com/ZiqiangStudio/zq_auth_sdk_python/actions/workflows/test.yml">
    <img src="https://github.com/ZiqiangStudio/zq_auth_sdk_python/actions/workflows/test.yml/badge.svg" alt="CI">
  </a>
  <a href="https://zq_auth_sdk_python.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/zq-django-util/badge/?version=latest" alt="Documentation Status" />
  </a>
  <a href="https://codecov.io/gh/ZiqiangStudio/zq_auth_sdk_python" >
    <img src="https://codecov.io/gh/ZiqiangStudio/zq_auth_sdk_python/branch/master/graph/badge.svg" alt="cov"/>
  </a>
  <a href="https://pypi.org/project/zq-django-util/">
  <img src="https://img.shields.io/pypi/v/zq-django-util" alt="pypi">
  </a>
</p>
<!-- markdownlint-enable MD033 -->

## 简介

## 依赖需求

- Python 3.9+

## 安装

- 安装 zq-auth-sdk 包

使用 `pip` 安装：
```shell
pip install zq-auth-sdk
```

使用 `poetry` 安装：
```shell
poetry add zq-auth-sdk
```

- 使用 zq-django-util

> TODO
